==> haskell-hls-splice-plugin-2.1.0.0-32-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-splice-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-splice-plugin
version:              2.1.0.0
visibility:           public
id:                   hls-splice-plugin-2.1.0.0-74kGnlN6udg6VwV3TL4lwE
key:                  hls-splice-plugin-2.1.0.0-74kGnlN6udg6VwV3TL4lwE
license:              Apache-2.0
maintainer:
    https://github.com/haskell/haskell-language-server/contributors

author:
    https://github.com/haskell/haskell-language-server/contributors

synopsis:
    HLS Plugin to expand TemplateHaskell Splices and QuasiQuotes

description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  9891575396e8aeabdb8bc225043d347d
exposed:              True
exposed-modules:      Ide.Plugin.Splice Ide.Plugin.Splice.Types
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hls-splice-plugin-2.1.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hls-splice-plugin-2.1.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hls-splice-plugin-2.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-splice-plugin
hs-libraries:         HShls-splice-plugin-2.1.0.0-74kGnlN6udg6VwV3TL4lwE
depends:
    aeson-2.1.2.1-BWqAP5DPS0iMNSAJtMWSf base-4.17.2.1 containers-0.6.7
    dlist-1.0-BKgPi70fx5AJreCYiKxIIN
    extra-1.7.16-5rwblNHIKnAJW8xVzxUUh1
    foldl-1.4.18-67cKbmurAnyCIevCYqTGvI ghc-9.4.8
    ghc-exactprint-1.6.1-HNnqDtSHtBt5cvc6Os83Vs
    ghcide-2.1.0.0-HjJcIrZ7EZPJxbts2S8m1R
    hls-plugin-api-2.1.0.0-KVOZ1lYMH8RFN5Pm8qtNxk
    hls-refactor-plugin-2.1.0.0-D48hR4GoKvULBLEtUs8dIG
    lens-5.3.1-L3T26fDKV8KAh84K9wN8lF lsp-2.1.0.0-G1dFdKfwoxaRIfZIBWGTA
    mtl-2.2.2 retrie-1.2.3-gNXL79ItrMBb6s7zm9p08
    syb-0.7.2.4-BSKNIdKaKEZCAuXcVMqAaV text-2.0.2 transformers-0.5.6.2
    unliftio-core-0.2.1.0-1JwPsdkrVim6892Z5vBeIT
    unordered-containers-0.2.20-G9Xtyt8hv5K8HhfrH8JX1r

haddock-interfaces:
    /usr/share/doc/haskell-hls-splice-plugin/html/hls-splice-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-splice-plugin/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hls-splice-plugin-2.1.0.0-33-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-splice-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-splice-plugin
version:              2.1.0.0
visibility:           public
id:                   hls-splice-plugin-2.1.0.0-8UqEbLW4ZFUKMbkAX5DB4G
key:                  hls-splice-plugin-2.1.0.0-8UqEbLW4ZFUKMbkAX5DB4G
license:              Apache-2.0
maintainer:
    https://github.com/haskell/haskell-language-server/contributors

author:
    https://github.com/haskell/haskell-language-server/contributors

synopsis:
    HLS Plugin to expand TemplateHaskell Splices and QuasiQuotes

description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  cb5555bc732fd8de8f2c9bdcbcf5159c
exposed:              True
exposed-modules:      Ide.Plugin.Splice Ide.Plugin.Splice.Types
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hls-splice-plugin-2.1.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hls-splice-plugin-2.1.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hls-splice-plugin-2.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-splice-plugin
hs-libraries:         HShls-splice-plugin-2.1.0.0-8UqEbLW4ZFUKMbkAX5DB4G
depends:
    aeson-2.1.2.1-JD8QPsoBF4NC1qVY6ch6us base-4.17.2.1 containers-0.6.7
    dlist-1.0-BKgPi70fx5AJreCYiKxIIN
    extra-1.7.16-1RhoiOXPfr67YmwKq5VFCS
    foldl-1.4.18-7s4xVKL4dJrBHUFD4UvqIs ghc-9.4.8
    ghc-exactprint-1.6.1-6RlJtfQnbY81YB1XqWWj4q
    ghcide-2.1.0.0-Hg0pGiS6ziTEMpYkdxEh61
    hls-plugin-api-2.1.0.0-9I00cdszhZi41UevDTuK1a
    hls-refactor-plugin-2.1.0.0-Ls0m3NQB1EeBCKUGu3zvJC
    lens-5.3.1-JV4NgTTRRUD4MjO8VGr2iB
    lsp-2.1.0.0-L0nY2m9p5xP4ItlDGFfaVG mtl-2.2.2
    retrie-1.2.3-DZuIMd4KFRJGRA1cO9U4Cw
    syb-0.7.2.4-5o1aA7VmoIW8wlDGJbJzgh text-2.0.2 transformers-0.5.6.2
    unliftio-core-0.2.1.0-1JwPsdkrVim6892Z5vBeIT
    unordered-containers-0.2.20-ASGEyX3xTBf3ZK5sYSGlF8

haddock-interfaces:
    /usr/share/doc/haskell-hls-splice-plugin/html/hls-splice-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-splice-plugin/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
